[Python-checkins] Update outdated `LOAD_METHOD` comments in `Python/ceval.c` (GH-92641)

Fidget-Spinner webhook-mailer at python.org
Thu May 12 08:38:00 EDT 2022


https://github.com/python/cpython/commit/bdf99691972c4e452a86eb3ca7ff7ae748d881a6
commit: bdf99691972c4e452a86eb3ca7ff7ae748d881a6
branch: main
author: Crowthebird <78076854+thatbirdguythatuknownot at users.noreply.github.com>
committer: Fidget-Spinner <kenjin4096 at gmail.com>
date: 2022-05-12T20:37:55+08:00
summary:

Update outdated `LOAD_METHOD` comments in `Python/ceval.c` (GH-92641)

files:
M Python/ceval.c

diff --git a/Python/ceval.c b/Python/ceval.c
index b2735a1b2d395..f6b07b4b28eb6 100644
--- a/Python/ceval.c
+++ b/Python/ceval.c
@@ -4537,7 +4537,7 @@ _PyEval_EvalFrameDefault(PyThreadState *tstate, _PyInterpreterFrame *frame, int
 
         TARGET(LOAD_METHOD) {
             PREDICTED(LOAD_METHOD);
             /* Designed to work in tandem with CALL_METHOD. */
             PyObject *name = GETITEM(names, oparg);
             PyObject *obj = TOP();
             PyObject *meth = NULL;
@@ -4562,7 +4562,7 @@ _PyEval_EvalFrameDefault(PyThreadState *tstate, _PyInterpreterFrame *frame, int
                 /* meth is not an unbound method (but a regular attr, or
                    something was returned by a descriptor protocol).  Set
                    the second element of the stack to NULL, to signal
-                   CALL_METHOD that it's not a method call.
+                   PRECALL that it's not a method call.
 
                    NULL | meth | arg1 | ... | argN
                 */
@@ -4537,7 +4537,7 @@ _PyEval_EvalFrameDefault(PyThreadState *tstate, _PyInterpreterFrame *frame, int
         TARGET(LOAD_METHOD) {
             PREDICTED(LOAD_METHOD);
-            /* Designed to work in tandem with CALL_METHOD. */
+            /* Designed to work in tandem with PRECALL. */
             PyObject *name = GETITEM(names, oparg);
             PyObject *obj = TOP();



More information about the Python-checkins mailing list